@@ -1,3 +1,8 @@
+/* This file is a part of @mdn/browser-compat-data
+ * See LICENSE file for more information. */
+
+'use strict';
+
 const yargs = require('yargs');
 
 const fs = require('fs');
@@ -28,7 +33,7 @@ function enumerateFeatures(dataFrom) {
 const { argv } = yargs.command(
   '$0 [dest]',
   'Write a JSON-formatted list of feature paths',
-  yargs => {
+  (yargs) => {
     yargs
       .positional('dest', {
         default: '.features.json',
