@@ -1,5 +1,9 @@
+/* This file is a part of @mdn/browser-compat-data
+ * See LICENSE file for more information. */
+
 'use strict';
-const assert = require('assert');
+
+const assert = require('assert').strict;
 const { execSync } = require('child_process');
 
 const prebuiltPath = '../build';
