@@ -1,10 +1,20 @@
+/* This file is a part of @mdn/browser-compat-data
+ * See LICENSE file for more information. */
+
 'use strict';
-const Ajv = require('ajv');
+
+const Ajv = require('ajv').default;
+const ajvErrors = require('ajv-errors');
+const addFormats = require('ajv-formats');
 const betterAjvErrors = require('better-ajv-errors').default;
-const path = require('path');
 const chalk = require('chalk');
 
-const ajv = new Ajv({ jsonPointers: true, allErrors: true });
+const ajv = new Ajv({ allErrors: true });
+// We use 'fast' because as a side effect that makes the "uri" format more lax.
+// By default the "uri" format rejects ① and similar in URLs.
+addFormats(ajv, { mode: 'fast' });
+// Allow for custom error messages to provide better directions for contributors
+ajvErrors(ajv);
 
 /**
  * @param {string} dataFilename
@@ -27,7 +37,7 @@ function testSchema(
     );
     // Output messages by one since better-ajv-errors wrongly joins messages
     // (see https://github.com/atlassian/better-ajv-errors/pull/21)
-    ajv.errors.forEach(e => {
+    ajv.errors.forEach((e) => {
       console.error(betterAjvErrors(schema, data, [e], { indent: 2 }));
     });
     return true;
