@@ -1,5 +1,13 @@
+/* This file is a part of @mdn/browser-compat-data
+ * See LICENSE file for more information. */
+
+'use strict';
+
 const chalk = require('chalk');
 
+/** @type {string[]} */
+const VALID_ELEMENTS = ['code', 'kbd', 'em', 'strong', 'a'];
+
 class Logger {
   /** @param {string} title */
   constructor(title) {
@@ -31,4 +39,4 @@ class Logger {
   }
 }
 
-module.exports = { Logger };
+module.exports = { VALID_ELEMENTS, Logger };
