@@ -1,5 +1,9 @@
+/* This file is a part of @mdn/browser-compat-data
+ * See LICENSE file for more information. */
+
 'use strict';
-const assert = require('assert');
+
+const assert = require('assert').strict;
 const { escapeInvisibles } = require('./utils.js');
 
 describe('utils', () => {
@@ -49,7 +53,7 @@ describe('utils', () => {
       } else {
         [char, expected = char] = data;
       }
-      assert.strictEqual(escapeInvisibles(char), expected);
+      assert.equal(escapeInvisibles(char), expected);
     }
   });
 });
