@@ -1,3 +1,8 @@
+/* This file is a part of @mdn/browser-compat-data
+ * See LICENSE file for more information. */
+
+'use strict';
+
 const iterSupport = require('./iter-support');
 const query = require('./query');
 const { walk } = require('./walk');
