@@ -1,3 +1,8 @@
+/* This file is a part of @mdn/browser-compat-data
+ * See LICENSE file for more information. */
+
+'use strict';
+
 function iterSupport(compat, browser) {
   if (browser in compat.support) {
     const data = compat.support[browser];
